regr_easy_calc: Calculation of Regression Models: Linear, Quadratic and Cubic.
Description
Performs regression calculations: linear, quadratic and cubic, allowing to perform only one or both, returning a detailed result of the calculation
Usage
regr_easy_calc(x, y, model = "all")
Value
returns a list with the regression result (linear, quadratic and/or cube)
Arguments
x
Values that should be used as an independent variable for the regression calculation.
y
Values that should be used as a dependent variable for the regression calculation.
model
Character, defined which model will be calculated. model = "L", calculate the linear, model = "Q" calculate the quadratic, model = "C" calculate the cubic, model = "all" = calculate both).